@@ -77,22 +77,22 @@ on_window1_realize                     (GtkWidget       *widget,
 {
   struct gok_window_realize_data *window_realize_data = (struct gok_window_realize_data *) user_data;
   GdkKeymap *map = gdk_keymap_get_default ();
+  GdkWindow *window;
 
   gok_main_center_corepointer (widget);
+  window = gtk_widget_get_window (widget);
 
   if (window_realize_data->is_dock) {
 	  gok_main_set_wm_dock (TRUE);
   }
   else {
-	  if (widget->window) {
-		  gdk_window_set_decorations (widget->window, GDK_DECOR_ALL | GDK_DECOR_MINIMIZE | GDK_DECOR_MAXIMIZE);
-		  gdk_window_set_functions (widget->window, GDK_FUNC_MOVE | GDK_FUNC_RESIZE);
-	  }
+	  gdk_window_set_decorations (window, GDK_DECOR_ALL | GDK_DECOR_MINIMIZE | GDK_DECOR_MAXIMIZE);
+	  gdk_window_set_functions (window, GDK_FUNC_MOVE | GDK_FUNC_RESIZE);
   }
 
   gtk_window_stick (GTK_WINDOW (widget));
 
-  if (!gok_keyboard_xkb_select (GDK_WINDOW_XDISPLAY (widget->window)))
+  if (!gok_keyboard_xkb_select (GDK_WINDOW_XDISPLAY (window)))
 	  g_warning ("Could not register for XKB events!");
   
   if (window_realize_data->use_libusb == FALSE) {
