@@ -1,4 +1,27 @@
+/*
+ * callbacks.h
+ *
+ * Copyright 2002-2009 Sun Microsystems, Inc.,
+ * Copyright 2002-2009 University Of Toronto
+ * Copyright 2009 Gerd Kohlberger <gerdko gmail com>
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
+ */
 
+#include <gtk/gtk.h>
 
 void
 on_window1_realize                     (GtkWidget       *widget,
@@ -85,11 +108,8 @@ on_window1_leave_notify_event         (GtkWidget        *widget,
 				       gpointer          user_data);
 
 void
-on_entryName_changed                   (GtkEditable     *editable,
-                                        gpointer         user_data);
-void
-on_entry_input_device_changed          (GtkEditable     *editable,
-                                        gpointer         user_data);
+on_comboInputDevice_changed           (GtkComboBox     *combo,
+                                       gpointer         data);
 
 gboolean
 on_dialogSettings_delete_event         (GtkWidget       *widget,
@@ -151,8 +171,8 @@ on_radiobuttonTypeMousePointer_toggled (GtkToggleButton *togglebutton,
                                         gpointer         user_data);
 
 void
-on_entryActionName_changed               (GtkEditable     *editable,
-                                        gpointer         user_data);
+on_comboActionNames_changed            (GtkComboBox     *combo,
+                                        gpointer         data);
 
 void
 on_buttonNewAction_clicked             (GtkButton       *button,
@@ -162,7 +182,6 @@ void
 on_checkWordCompletion_toggled         (GtkToggleButton *togglebutton,
                                         gpointer         user_data);
 
-
 void
 on_buttonNewAction_clicked             (GtkButton       *button,
                                         gpointer         user_data);
@@ -183,31 +202,6 @@ void
 on_buttonAccessMethodWizard_clicked    (GtkButton       *button,
                                         gpointer         user_data);
 
-gboolean
-on_comboActionNames_focus_out_event    (GtkWidget       *widget,
-                                        GdkEventFocus   *event,
-                                        gpointer         user_data);
-
-gboolean
-on_entryActionName_focus_out_event     (GtkWidget       *widget,
-                                        GdkEventFocus   *event,
-                                        gpointer         user_data);
-
-gboolean
-on_spinSwitchDelay_focus_in_event      (GtkWidget       *widget,
-                                        GdkEventFocus   *event,
-                                        gpointer         user_data);
-
-gboolean
-on_comboActionNames_focus_out_event    (GtkWidget       *widget,
-                                        GdkEventFocus   *event,
-                                        gpointer         user_data);
-
-gboolean
-on_entryActionName_leave_notify_event  (GtkWidget       *widget,
-                                        GdkEventCrossing *event,
-                                        gpointer         user_data);
-
 void
 on_buttonChangeName_clicked            (GtkButton       *button,
                                         gpointer         user_data);
@@ -421,28 +415,24 @@ on_buttonFeedbackSoundFile_clicked     (GtkButton       *button,
                                         gpointer         user_data);
 
 void
-on_entry63_changed                     (GtkEditable     *editable,
-                                        gpointer         user_data);
+on_comboFeedback_changed               (GtkComboBox     *combo,
+                                        gpointer         data);
 
 void
-on_entryFeedback_changed               (GtkEditable     *editable,
-                                        gpointer         user_data);
-
-void
-on_checkKeyFlashing_clicked            (GtkButton       *button,
-                                        gpointer         user_data);
+on_checkKeyFlashing_toggled            (GtkToggleButton *button,
+                                        gpointer         data);
 
 void
 on_spinKeyFlashing_changed             (GtkEditable     *editable,
                                         gpointer         user_data);
 
 void
-on_checkSoundOn_clicked                (GtkButton       *button,
-                                        gpointer         user_data);
+on_checkSoundOn_toggled                (GtkToggleButton *button,
+                                        gpointer         data);
 
 void
-on_entrySoundName_changed              (GtkEditable     *editable,
-                                        gpointer         user_data);
+on_comboSoundName_changed              (GtkComboBox     *combo,
+                                        gpointer         data);
 
 void
 on_notebook2_switch_page               (GtkNotebook     *notebook,
@@ -472,10 +462,6 @@ void
 on_spinSpacing_changed                 (GtkEditable     *editable,
                                         gpointer         user_data);
 
-void
-on_entryActionName_changed               (GtkEditable     *editable,
-                                        gpointer         user_data);
-
 void
 on_buttonNewAction_clicked             (GtkButton       *button,
                                         gpointer         user_data);
@@ -592,10 +578,6 @@ void
 on_checkKeyFlashing_clicked            (GtkButton       *button,
                                         gpointer         user_data);
 
-void
-on_entrySoundName_changed              (GtkEditable     *editable,
-                                        gpointer         user_data);
-
 void
 on_buttonFeedbackSoundFile_clicked     (GtkButton       *button,
                                         gpointer         user_data);
@@ -649,8 +631,8 @@ on_checkKeyAverage_toggled             (GtkToggleButton *togglebutton,
                                         gpointer         user_data);
 
 void
-on_entryName_changed                   (GtkEditable     *editable,
-                                        gpointer         user_data);
+on_comboAccessMethods_changed          (GtkComboBox     *combo,
+                                        gpointer         data);
 
 void
 on_new1_activate                       (GtkMenuItem     *menuitem,
