@@ -2,6 +2,7 @@
 *
 * Copyright 2002-2009 Sun Microsystems, Inc.,
 * Copyright 2001-2009 University Of Toronto
+* Copyright 2009 Gerd Kohlberger <gerdko gmail com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
@@ -207,8 +208,7 @@ gint gok_button_leave_notify   (GtkWidget *widget, GdkEventCrossing   *event)
 
 	if (GOK_IS_BUTTON (widget))
 	{
-		gdk_drawable_get_size (GTK_BUTTON (widget)->event_window,
-				       &x, &y);
+		gdk_drawable_get_size (event->window, &x, &y);
 		if (event->x <= 0 || event->x >= x ||
 		    event->y <= 0 || event->y >= y)
 		{
@@ -278,10 +278,11 @@ static gboolean
 gok_button_expose (GtkWidget      *widget,
 		   GdkEventExpose *event)
 {
+	GtkAllocation image_alloc;
  	gboolean retval = 
 		(* GTK_WIDGET_CLASS (gok_button_parent_class)->expose_event) (widget, event);
 	
-	if (GTK_WIDGET_DRAWABLE (widget) && GOK_BUTTON (widget)->pImage) {
+	if (gtk_widget_is_drawable (widget) && GOK_BUTTON (widget)->pImage) {
 		if (GOK_BUTTON (widget)->indicator_type != NULL) {
 			GtkWidget *image = GOK_BUTTON (widget)->pImage;
 			GdkRectangle rect;
@@ -290,15 +291,16 @@ gok_button_expose (GtkWidget      *widget,
 			   gtk_widget_style_get (image, "indicator_size", &indicator_size, 
 			   "indicator_spacing", &indicator_spacing, NULL);
 			*/
-			rect.x = image->allocation.x + (image->allocation.width - indicator_size)/2;
+			gtk_widget_get_allocation (image, &image_alloc);
+			rect.x = image_alloc.x + (image_alloc.width - indicator_size)/2;
 			/* "20" is size of standard status images we use. kludge. */
-			rect.y = image->allocation.y + (image->allocation.height - indicator_size)/2;
+			rect.y = image_alloc.y + (image_alloc.height - indicator_size)/2;
 			rect.width = indicator_size;
 			rect.height = indicator_size;
 			if (*(GOK_BUTTON (widget)->indicator_type) == 'r') {
 				gtk_paint_option (gtk_widget_get_style (image),
 						  gtk_widget_get_parent_window (image),
-						  GTK_WIDGET_STATE (image),
+						  gtk_widget_get_state (image),
 						  (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget))) ? 
 						  GTK_SHADOW_IN : GTK_SHADOW_OUT,
 						  &rect,
@@ -318,7 +320,7 @@ gok_button_expose (GtkWidget      *widget,
 				gtk_paint_polygon (gtk_widget_get_style (widget),
 						   gtk_widget_get_parent_window (image),
 						   gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget)) ?
-						   GTK_STATE_PRELIGHT : GTK_WIDGET_STATE (widget),
+						   GTK_STATE_PRELIGHT : gtk_widget_get_state (widget),
 						   GTK_SHADOW_IN,
 						   &rect,
 						   image,
@@ -331,7 +333,7 @@ gok_button_expose (GtkWidget      *widget,
 			else {
 				gtk_paint_check (gtk_widget_get_style (image),
 						 gtk_widget_get_parent_window (image),
-						 GTK_WIDGET_STATE (image),
+						 gtk_widget_get_state (image),
 						 (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget))) ? 
 						 GTK_SHADOW_IN : GTK_SHADOW_OUT,
 						 &rect,
