@@ -2,6 +2,7 @@
 *
 * Copyright 2001-2009 Sun Microsystems, Inc.,
 * Copyright 2001-2009 University Of Toronto
+* Copyright 2009 Gerd Kohlberger <gerdko gmail com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
@@ -469,28 +470,44 @@ gok_key_keycode_from_xkb_key (XkbKeyPtr keyp, XkbDescPtr kbd)
 gint
 gok_key_get_default_border_width (GokKey *pKey)
 {
+	GtkStyle *style;
+	gint border_width;
+
 	if (pKey->pButton)
-		return GTK_CONTAINER (pKey->pButton)->border_width + 
-			CHILD_SPACING +
-			GTK_WIDGET (pKey->pButton)->style->xthickness;
-	else
-		return 0;
+	{
+		border_width = gtk_container_get_border_width (GTK_CONTAINER (pKey->pButton));
+		style = gtk_widget_get_style (pKey->pButton);
+		return border_width + CHILD_SPACING + style->xthickness;
+	}
+	return 0;
 }
 
 static gint
 gok_key_get_default_font_size (GokKey *pKey)
 {
-        PangoFontDescription *font_desc = 
-	        GTK_WIDGET (pKey->pButton)->style->font_desc;
-        return PANGO_PIXELS (pango_font_description_get_size (font_desc));
+	GtkStyle *style;
+
+	if (pKey->pButton)
+	{
+		style = gtk_widget_get_style (pKey->pButton);
+		return PANGO_PIXELS (pango_font_description_get_size (style->font_desc));
+	}
+	return 0;
 }
 
 static gint
 gok_key_get_default_border_height (GokKey *pKey)
 {
-        return GTK_CONTAINER (pKey->pButton)->border_width + 
-                CHILD_SPACING + 
-                GTK_WIDGET (pKey->pButton)->style->ythickness;
+	GtkStyle *style;
+	gint border_width;
+
+	if (pKey->pButton)
+	{
+		border_width = gtk_container_get_border_width (GTK_CONTAINER (pKey->pButton));
+		style = gtk_widget_get_style (pKey->pButton);
+		return border_width + CHILD_SPACING + style->ythickness;
+	}
+	return 0;
 }
 
 /**
@@ -681,7 +698,6 @@ GokKey* gok_key_new (GokKey* pKeyPrevious, GokKey* pKeyNext, GokKeyboard* pKeybo
 	pgok_key_new->BottomWin = 0;
 	pgok_key_new->LeftWin = 0;
 	pgok_key_new->RightWin = 0;
-	pgok_key_new->pMimicKey = NULL;
 	pgok_key_new->pKeyNext = pKeyNext;
 	pgok_key_new->pKeyPrevious = pKeyPrevious;
 	pgok_key_new->accessible_node = NULL;
