@@ -69,7 +69,7 @@ gok_output_update_predictions (GokOutput    *output,
 		case OUTPUT_KEYCODE:
 		case OUTPUT_KEYSYM:
 			prediction_list = gok_wordcomplete_process_and_predict (complete,
-										(gunichar) data,
+										GPOINTER_TO_UINT (data),
 										gok_data_get_num_predictions ());
 			part = gok_wordcomplete_get_word_part (complete);
 			if (gok_wordcomplete_validate_word (complete, part)) { 
@@ -183,8 +183,7 @@ GokOutput* gok_output_new (gint Type, gchar* Name, AccessibleKeySynthType Flag)
 	pNewOutput->pOutputNext = NULL;
 	pNewOutput->Flag = Flag;
 	pNewOutput->Type = Type;
-	pNewOutput->Name = (gchar*)g_malloc (strlen (Name) + 1);
-	strcpy (pNewOutput->Name, Name);
+	pNewOutput->Name = g_strdup (Name);
 
 	return pNewOutput;
 }
@@ -365,13 +364,13 @@ void gok_output_send_to_system (GokOutput* pOutput, gboolean bWordCompletion)
 				if (last_dead_key && unichar) {
 					gchar *s;
 					s = gok_wordcomplete_process_unichar (gok_wordcomplete_get_default (), unichar);
-					gok_output_update_predictions (pOutput, 
-								       (gpointer) gok_output_unichar_postfix_from_deadkey (last_dead_key));
+					gok_output_update_predictions (pOutput,
+								       GUINT_TO_POINTER (gok_output_unichar_postfix_from_deadkey (last_dead_key)));
 					last_dead_key = 0;
 				}
 				else if (unichar) {
 					gok_output_update_predictions (pOutput, 
-								       (gpointer) unichar);
+								       GUINT_TO_POINTER (unichar));
 				}
 			}
 		}
@@ -409,12 +408,12 @@ void gok_output_send_to_system (GokOutput* pOutput, gboolean bWordCompletion)
 					gchar *s;
 					s = gok_wordcomplete_process_unichar (gok_wordcomplete_get_default (), unichar);
 					gok_output_update_predictions (pOutput, 
-								       (gpointer) gok_output_unichar_postfix_from_deadkey (last_dead_key));
+								       GUINT_TO_POINTER (gok_output_unichar_postfix_from_deadkey (last_dead_key)));
 					last_dead_key = 0;
 				}
 				else if (unichar) {
 					gok_output_update_predictions (pOutput, 
-								       (gpointer) unichar);
+								       GUINT_TO_POINTER (unichar));
 				}
 			}
 		}
@@ -458,9 +457,11 @@ void gok_output_send_to_system (GokOutput* pOutput, gboolean bWordCompletion)
 			if (strcmp("default:browser",pOutput->Name) == 0) {
 				/* special: default browser */
 				gchar* browser = NULL;
-				gok_gconf_get_string (gconf_client_get_default (),
-						GOK_GCONF_DEFAULT_BROWSER, &browser);
-				g_spawn_command_line_async (browser, NULL);
+				if (gok_gconf_get_string (gconf_client_get_default (),
+						GOK_GCONF_DEFAULT_BROWSER, &browser)) {
+					g_spawn_command_line_async (browser, NULL);
+				}
+				/* FIXME:  report an error */
 			}
 			else {
 				/* not special */
