@@ -2,6 +2,7 @@
 *
 * Copyright 2002-2009 Sun Microsystems, Inc.,
 * Copyright 2002-2009 University Of Toronto
+* Copyright 2009 Gerd Kohlberger <gerdko gmail com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
@@ -58,22 +59,17 @@ static GokFilledCombo* m_pGokFilledComboFirst;
 
 /**
 * gok_page_accessmethod_initialize
-* @xml: Pointer to the Glade UI description of the settings dialog.
 *
 * Initializes this page of the gok settings dialog. This must be called
 * prior to any calls on this page.
 *
 * returns: TRUE if the page was properly initialized, FALSE if not.
 **/
-gboolean gok_page_accessmethod_initialize (GladeXML* xml)
+gboolean gok_page_accessmethod_initialize (void)
 {
 	GokAccessMethod* pAccessMethod;
-	GtkWidget* pComboBox;
-	GtkWidget* pEntryAccessMethodName;
-	GList* items = NULL;
-		
-	g_assert (xml != NULL);
-	
+	GtkComboBox *combo;
+
 	/* initialize this data */
 	m_NameAccessMethod = g_strdup (gok_data_get_name_accessmethod());
 	m_bUsChangingName = FALSE;
@@ -87,30 +83,21 @@ gboolean gok_page_accessmethod_initialize (GladeXML* xml)
 	pAccessMethod = gok_scanner_get_first_access_method();
 	g_assert (pAccessMethod != NULL);
 	
-	pComboBox = glade_xml_get_widget (xml,  "comboAccessMethods");
-	g_assert (pComboBox != NULL);
-	
+	combo = GTK_COMBO_BOX (OID ("comboAccessMethods"));
+	gok_settingsdialog_combobox_init (combo, TRUE);
 	while (pAccessMethod != NULL)
 	{
-		items = g_list_append (items, pAccessMethod->DisplayName);
+		gtk_combo_box_prepend_text (combo, pAccessMethod->DisplayName);
 		pAccessMethod = pAccessMethod->pAccessMethodNext;
 	}
 
-	/* sort the names */
-	items = g_list_sort (items, gok_settingsdialog_sort);
-
 	m_bUsChangingName = TRUE;
-	gtk_combo_set_popdown_strings (GTK_COMBO (pComboBox), items);
-	g_list_free (items);
-
-	/* display the current access method */
-	pEntryAccessMethodName = glade_xml_get_widget (xml, "entryAccessMethodName");
-	g_assert (pEntryAccessMethodName != NULL);
-	gtk_entry_set_text (GTK_ENTRY (pEntryAccessMethodName), gok_page_accessmethod_get_displayname (m_NameAccessMethod));
+	gok_settingsdialog_combobox_set_active (combo,
+						gok_page_accessmethod_get_displayname (m_NameAccessMethod));
 	m_bUsChangingName = FALSE;
 
 	/* update the accessmethod controls */
-	gok_page_accessmethod_method_changed (GTK_EDITABLE (pEntryAccessMethodName));
+	gok_page_accessmethod_method_changed (combo);
 
 	return TRUE;
 }
@@ -255,7 +242,7 @@ gboolean gok_page_accessmethod_apply_controls (GokControl* pControl, gchar* Name
 {
 	const gchar* pText;
 	const gchar* pType;
-	GtkWidget* pEntry;
+	gchar *entry;
 	gint valueNew;
 	gboolean bTrueFalse;
 	GSList* pRadioList;
@@ -274,20 +261,20 @@ gboolean gok_page_accessmethod_apply_controls (GokControl* pControl, gchar* Name
 			switch (pControl->Type)
 			{
 				case CONTROL_TYPE_COMBOBOX:
-					pEntry = GTK_COMBO(pControl->pWidget)->entry;
-					pText = gtk_entry_get_text (GTK_ENTRY(pEntry));
+					entry = gtk_combo_box_get_active_text (GTK_COMBO_BOX (pControl->pWidget));
 
 					/* convert the display name to the static (gconf) name */
 					pType = g_object_get_data (G_OBJECT(pControl->pWidget), "type");
 					if (pType != NULL)
 					{
+						pText = NULL;
 						if (strcmp (pType, "actions") == 0)
 						{
-							pText = gok_action_get_name ((gchar*)pText);
+							pText = gok_action_get_name (entry);
 						}
 						else if (strcmp (pType, "feedbacks") == 0)
 						{
-							pText = gok_feedback_get_name ((gchar*)pText);
+							pText = gok_feedback_get_name (entry);
 						}
 						else if (strcmp (pType, "sounds") == 0)
 						{
@@ -307,6 +294,7 @@ gboolean gok_page_accessmethod_apply_controls (GokControl* pControl, gchar* Name
 							codeReturned = TRUE;
 						}
 					}
+					g_free (entry);
 					break;
 					
 				case CONTROL_TYPE_CHECKBUTTON:
@@ -422,14 +410,14 @@ void gok_page_accessmethod_backup ()
 * The user has selected a new access method so display all the controls
 * associated with that access method.
 **/
-void gok_page_accessmethod_method_changed (GtkEditable* pEditControl)
+void gok_page_accessmethod_method_changed (GtkComboBox *combo)
 {
 	gchar* pStringMethodName;
 	gchar* pAccessMethodName;
 	
 	/* first, get the name of the access method */
-	pStringMethodName = gtk_editable_get_chars (pEditControl, 0, -1);
-	if (strlen (pStringMethodName) != 0)
+	pStringMethodName = gtk_combo_box_get_active_text (combo);
+	if (pStringMethodName && strlen (pStringMethodName) != 0)
 	{
 		/* did the user change the name or did we? */
 		if (m_bUsChangingName == FALSE)
@@ -487,9 +475,9 @@ void gok_page_accessmethod_update_controls (gchar* NameAccessMethod, GokControl*
 							
 							if (pControl->pWidget != NULL)
 							{
-								pEntry = GTK_COMBO(pControl->pWidget)->entry;
-								g_assert (pEntry != NULL);
-								gtk_entry_set_text (GTK_ENTRY (pEntry), settingString);
+								gok_settingsdialog_combobox_set_active (
+										GTK_COMBO_BOX (pControl->pWidget),
+										settingString);
 							}
 						}
 					}
@@ -638,7 +626,8 @@ void gok_page_accessmethod_draw_controls (gchar* NameAccessMethod, GokControl* p
 						
 					case CONTROL_TYPE_COMBOBOX:
 						pControlName = (pControl->Name != NULL) ? pControl->Name : "combobox";
-						pWidget = gtk_combo_new ();
+						pWidget = gtk_combo_box_new ();
+						gok_settingsdialog_combobox_init (GTK_COMBO_BOX (pWidget), TRUE);
 						g_object_ref (pWidget);
 						g_object_set_data_full (G_OBJECT (gok_settingsdialog_get_window ()),
 									pControlName, pWidget,
@@ -648,10 +637,6 @@ void gok_page_accessmethod_draw_controls (gchar* NameAccessMethod, GokControl* p
 						gtk_widget_show (pWidget);
 						gtk_box_pack_start (GTK_BOX (pControlParent->pWidget), pWidget, FALSE, FALSE, 0);
 
-						/* make the combo's entry field NOT editable */
-						pEntry = GTK_COMBO (pWidget)->entry;
-						gtk_editable_set_editable (GTK_EDITABLE (pEntry), FALSE);
-						
 						/* create a new object to hold info about the filled combo */
 						/* the combo gets filled in gok_page_accessmethod_fill_combos */
 						pFilledComboNew = (GokFilledCombo*)g_malloc (sizeof (GokFilledCombo));
@@ -907,16 +892,11 @@ void gok_page_accessmethod_checkbox_changed (GtkButton* pButton, gpointer data)
 void gok_page_accessmethod_change_controls (gchar* pNameAccessMethod)
 {
 	GokAccessMethod* pAccessMethod;
-	GtkWidget* pLabelDescription;
-	GtkWidget* pEntryAccessMethodName;
 	GokControl ControlParent;
-	GtkWidget* pFrame;
 
 	g_assert (pNameAccessMethod != NULL);
 
-	pFrame = glade_xml_get_widget (gok_settingsdialog_get_xml(), "AccessMethodsTab");
-	g_assert (pFrame != NULL);
-	ControlParent.pWidget = pFrame;
+	ControlParent.pWidget = WID ("AccessMethodsTab");
 	ControlParent.Type = CONTROL_TYPE_FRAME;
 
 	/* find the access method in our list */
@@ -940,15 +920,12 @@ void gok_page_accessmethod_change_controls (gchar* pNameAccessMethod)
 			
 			/* display the name in the combo box */
 			m_bUsChangingName = TRUE;
-			pEntryAccessMethodName = glade_xml_get_widget (gok_settingsdialog_get_xml(), "entryAccessMethodName");
-			g_assert (pEntryAccessMethodName != NULL);
-			gtk_entry_set_text (GTK_ENTRY (pEntryAccessMethodName), gok_page_accessmethod_get_displayname (pNameAccessMethod));
+			gok_settingsdialog_combobox_set_active (GTK_COMBO_BOX (OID ("comboAccessMethods")),
+								gok_page_accessmethod_get_displayname (pNameAccessMethod));
 			m_bUsChangingName = FALSE;
 			
 			/* change the access method description text */
-			pLabelDescription = glade_xml_get_widget (gok_settingsdialog_get_xml(), "labelAmDescription");
-			g_assert (pLabelDescription != NULL);
-			gtk_label_set_text (GTK_LABEL (pLabelDescription), pAccessMethod->Description);
+			gtk_label_set_text (GTK_LABEL (OID ("labelAmDescription")), pAccessMethod->Description);
 				
 			/* display the controls for the selected access method */
 			gok_page_accessmethod_draw_controls (pNameAccessMethod, &ControlParent, pAccessMethod->pControlOperation, NULL, TRUE);
@@ -994,9 +971,9 @@ void gok_page_accessmethod_page_active()
 void gok_page_accessmethod_fill_combos (gboolean bRefill)
 {
 	GokFilledCombo* pGokFilledCombo;
+	GtkComboBox *combo;
 	GokAction* pAction;
 	GokFeedback* pFeedback;
-	GList* items;
 	int settingInt;
 	gchar* settingString;
 	GtkWidget* pEntry;
@@ -1008,9 +985,8 @@ void gok_page_accessmethod_fill_combos (gboolean bRefill)
 		  	(pGokFilledCombo->bFilled == FALSE))
 		{
 			pGokFilledCombo->bFilled = TRUE;
+			combo = GTK_COMBO_BOX (pGokFilledCombo->pCombo);
 
-			items = NULL;
-	
 			/* get the current setting string */
 			if (gok_data_get_setting (pGokFilledCombo->pNameAccessMethod, pGokFilledCombo->pNameControl, &settingInt, &settingString) == FALSE)
 			{
@@ -1028,8 +1004,7 @@ void gok_page_accessmethod_fill_combos (gboolean bRefill)
 						/* use only the actions specified by the 'qualifier' */
 						if (pAction->Type & pGokFilledCombo->Qualifier)
 						{
-							items = g_list_append (items, pAction->pDisplayName);
-											
+							gtk_combo_box_prepend_text (combo, pAction->pDisplayName);
 							/* get the display name from the setting name */
 							if (strcmp (pAction->pName, settingString) == 0)
 							{
@@ -1046,8 +1021,7 @@ void gok_page_accessmethod_fill_combos (gboolean bRefill)
 					pFeedback = gok_feedback_get_first_feedback();
 					while (pFeedback != NULL)
 					{
-						items = g_list_append (items, pFeedback->pDisplayName);
-											
+						gtk_combo_box_prepend_text (combo, pFeedback->pDisplayName);
 						/* get the display name from the setting name */
 						if (strcmp (pFeedback->pName, settingString) == 0)
 						{
@@ -1060,36 +1034,25 @@ void gok_page_accessmethod_fill_combos (gboolean bRefill)
 				case CONTROL_FILLWITH_SOUNDS:
 					g_object_set_data (G_OBJECT(pGokFilledCombo->pCombo), "type", "sounds");					
 	
-					items = g_list_append (items, "beep");
-					items = g_list_append (items, "boop");
-					items = g_list_append (items, "shreik");
-					items = g_list_append (items, "bang");
+					gtk_combo_box_prepend_text (combo, "beep");
+					gtk_combo_box_prepend_text (combo, "boop");
+					gtk_combo_box_prepend_text (combo, "shreik");
+					gtk_combo_box_prepend_text (combo, "bang");
 					break;
 									
 				case CONTROL_FILLWITH_OPTIONS:
 					g_object_set_data (G_OBJECT(pGokFilledCombo->pCombo), "type", "options");					
 	
-					items = g_list_append (items, "restart scanning");
-					items = g_list_append (items, "stop scanning");
-					items = g_list_append (items, "output character");
+					gtk_combo_box_prepend_text (combo, "restart scanning");
+					gtk_combo_box_prepend_text (combo, "stop scanning");
+					gtk_combo_box_prepend_text (combo, "output character");
 					break;
 									
 				default:
 					break;
 			}
-			if (items != NULL)
-			{
-				/* sort the names */
-				items = g_list_sort (items, gok_settingsdialog_sort);
-
-				gtk_combo_set_popdown_strings (GTK_COMBO (pGokFilledCombo->pCombo), items);
-				g_list_free (items);
-			}
-		
 			/* display the current setting */
-			pEntry = GTK_COMBO(pGokFilledCombo->pCombo)->entry;
-			g_assert (pEntry != NULL);
-			gtk_entry_set_text (GTK_ENTRY (pEntry), settingString);
+			gok_settingsdialog_combobox_set_active (combo, settingString);
 		}
 
 		pGokFilledCombo = pGokFilledCombo->pGokFilledComboNext;
