@@ -2,6 +2,7 @@
 *
 * Copyright 2004 Sun Microsystems, Inc.,
 * Copyright 2004 University Of Toronto
+* Copyright 2009 Gerd Kohlberger <gerdko gmail com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
@@ -19,9 +20,9 @@
 * Boston, MA 02111-1307, USA.
 */
 
-gboolean gok_page_keyboard_initialize (GladeXML* xml);
+gboolean gok_page_keyboard_initialize (void);
 void gok_page_keyboard_refresh (void);
 gboolean gok_page_keyboard_apply (void);
 gboolean gok_page_keyboard_revert (void);
 void gok_page_keyboard_backup (void);
-void gok_page_keyboard_update_custom_compose_from_control ();
+void gok_page_keyboard_update_custom_compose_from_control (void);
