@@ -2,6 +2,7 @@
 *
 * Copyright 2002 Sun Microsystems, Inc.,
 * Copyright 2002 University Of Toronto
+* Copyright 2009 Gerd Kohlberger <gerdko gmail com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
@@ -19,11 +20,10 @@
 * Boston, MA 02111-1307, USA.
 */
 
-gboolean gok_settings_page_keysizespace_initialize (GladeXML* xml);
+gboolean gok_settings_page_keysizespace_initialize (void);
 void gok_settings_page_keysizespace_refresh (void);
 gboolean gok_settings_page_keysizespace_ok (void);
 gboolean gok_settings_page_keysizespace_revert (void);
 void gok_settings_page_keysizespace_backup (void);
 gboolean gok_settings_page_keysizespace_apply (void);
 void gok_settings_page_keysizespace_display_keysizespacing (gint KeyWidth, gint KeyHeight, gint Space);
-void gok_settings_page_keysizespace_set_label_name (GtkWidget* pWidget);
