@@ -2,6 +2,7 @@
 *
 * Copyright 2002 Sun Microsystems, Inc.,
 * Copyright 2002 University Of Toronto
+* Copyright 2009 Gerd Kohlberger <gerdko gmail com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
@@ -23,7 +24,6 @@
 #  include <config.h>
 #endif
 #include <gtk/gtk.h>
-#include <glade/glade.h>
 #include "gok-page-wordcomplete.h"
 #include "gok-data.h"
 #include "gok-log.h"
@@ -55,12 +55,10 @@ void gok_page_wordcomplete_initialize_auxwordlist_control(const char* file);
 *
 * returns: TRUE if the page was properly initialized, FALSE if not.
 **/
-gboolean gok_page_wordcomplete_initialize (GladeXML* xml)
+gboolean gok_page_wordcomplete_initialize (void)
 {
 	GtkWidget* pWidget;
-	
-	g_assert (xml != NULL);
-		
+
 	m_WordCompleteOnOff = gok_data_get_wordcomplete();
 	m_NumberPredictions = gok_data_get_num_predictions();
 	m_bUseAuxDicts = gok_data_get_use_aux_dictionaries();
@@ -70,19 +68,14 @@ gboolean gok_page_wordcomplete_initialize (GladeXML* xml)
 	gok_page_wordcomplete_backup();
 
 	/* update the controls */
-	pWidget = glade_xml_get_widget (xml, "checkWordCompletion");
-	g_assert (pWidget != NULL);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pWidget), gok_data_get_wordcomplete());
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (OID ("checkWordCompletion")),
+				      m_WordCompleteOnOff);
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (OID ("spinNumberPredictions")),
+				   m_NumberPredictions);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (OID ("checkExtraWordList")),
+				      m_bUseAuxDicts);
 
-	pWidget = glade_xml_get_widget (xml, "spinNumberPredictions");
-	g_assert (pWidget != NULL);
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON(pWidget), gok_data_get_num_predictions());
-	
-	pWidget = glade_xml_get_widget (xml, "checkExtraWordList");
-	g_assert (pWidget != NULL);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pWidget), gok_data_get_use_aux_dictionaries());
-
-	gok_page_wordcomplete_initialize_auxwordlist_control((const char*)m_AuxDicts);
+	gok_page_wordcomplete_initialize_auxwordlist_control (m_AuxDicts);
 	
 	return TRUE;
 }
@@ -106,19 +99,13 @@ void gok_page_wordcomplete_refresh ()
 **/
 gboolean gok_page_wordcomplete_apply ()
 {
-	GtkWidget* pWidget;
 	gboolean bDataChanged;
 	gchar* text;
 	
 	bDataChanged = FALSE;
 
-	pWidget = glade_xml_get_widget (gok_settingsdialog_get_xml(), "checkWordCompletion");
-	g_assert (pWidget != NULL);
-	m_WordCompleteOnOff = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(pWidget));
-
-	pWidget = glade_xml_get_widget (gok_settingsdialog_get_xml(), "spinNumberPredictions");
-	g_assert (pWidget != NULL);
-	m_NumberPredictions = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(pWidget));
+	m_WordCompleteOnOff = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (OID ("checkWordCompletion")));
+	m_NumberPredictions = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (OID ("spinNumberPredictions")));
 
 	gok_page_wordcomplete_update_auxwordlist_from_control();
 	
@@ -168,11 +155,8 @@ gboolean gok_page_wordcomplete_revert ()
 		m_WordCompleteOnOff = m_WordCompleteOnOffBackup;
 		gok_data_set_wordcomplete (m_WordCompleteOnOff);
 		gok_keyslotter_on (m_WordCompleteOnOff, KEYTYPE_WORDCOMPLETE);
-
-		pWidget = glade_xml_get_widget (gok_settingsdialog_get_xml(), "checkWordCompletion");
-		g_assert (pWidget != NULL);
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pWidget), m_WordCompleteOnOff);
-
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (OID ("checkWordCompletion")),
+					      m_WordCompleteOnOff);
 	}
 
 	if (m_NumberPredictions != m_NumberPredictionsBackup)
@@ -181,10 +165,8 @@ gboolean gok_page_wordcomplete_revert ()
 		m_NumberPredictions = m_NumberPredictionsBackup;
 		gok_data_set_num_predictions (m_NumberPredictions);
 		gok_keyslotter_change_number_predictions (m_NumberPredictions, KEYTYPE_WORDCOMPLETE);
-
-		pWidget = glade_xml_get_widget (gok_settingsdialog_get_xml(), "spinNumberPredictions");
-		g_assert (pWidget != NULL);
-		gtk_spin_button_set_value (GTK_SPIN_BUTTON(pWidget), m_NumberPredictions);
+		gtk_spin_button_set_value (GTK_SPIN_BUTTON (OID ("spinNumberPredictions")),
+					   m_NumberPredictions);
 	}
 	
 	if (m_bUseAuxDicts != m_bUseAuxDictsBackup) {
@@ -193,10 +175,8 @@ gboolean gok_page_wordcomplete_revert ()
 		gok_data_set_use_aux_dictionaries (m_bUseAuxDicts);
 		/* TODO call rebuild internal dictionary */
 		gok_log ("TODO: Call to rebuild word completion model");
-
-		pWidget = glade_xml_get_widget (gok_settingsdialog_get_xml(), "checkExtraWordList");
-		g_assert (pWidget != NULL);
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pWidget), m_bUseAuxDicts);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (OID ("checkExtraWordList")),
+					      m_bUseAuxDicts);
 	}
 	
 	if (m_AuxDicts != m_AuxDictsBackup) {
@@ -206,11 +186,8 @@ gboolean gok_page_wordcomplete_revert ()
 		gok_data_set_aux_dictionaries (m_AuxDicts);
 		/* TODO call rebuild internal word completion list */
 		gok_log ("TODO: Call to rebuild word completion model");
-		
-		pWidget = glade_xml_get_widget (gok_settingsdialog_get_xml(), "DictionaryPathEntry");
-		g_assert (pWidget != NULL);
-		if (m_AuxDicts) gtk_entry_set_text (GTK_ENTRY (pWidget),m_AuxDicts); 
-		
+		if (m_AuxDicts) gtk_entry_set_text (GTK_ENTRY (OID ("DictionaryPathEntry")),
+						    m_AuxDicts);
 	}
 
 	return bDataChanged;
@@ -226,8 +203,9 @@ void gok_page_wordcomplete_backup ()
 	m_WordCompleteOnOffBackup = m_WordCompleteOnOff;
 	m_NumberPredictionsBackup = m_NumberPredictions;
 	m_bUseAuxDictsBackup = m_bUseAuxDicts;
-	if (m_AuxDicts) m_AuxDictsBackup = g_strdup (m_AuxDicts);
-	else m_AuxDictsBackup = NULL;
+
+	g_free (m_AuxDictsBackup);
+	m_AuxDictsBackup = m_AuxDicts ? g_strdup (m_AuxDicts) : NULL;
 }
 
 
@@ -243,32 +221,28 @@ gok_page_wordcomplete_toggle_wordlist (gboolean on)
 void 
 gok_page_wordcomplete_update_auxwordlist_from_control ()
 {
-	GtkWidget* pWidget; 
 	gchar* text;
-	
+
 	gok_log_enter();
-	pWidget = glade_xml_get_widget (gok_settingsdialog_get_xml(), "DictionaryPathEntry");
-	g_assert (pWidget != NULL);
-	text = (gchar *) g_strdup (gtk_entry_get_text ( GTK_ENTRY (pWidget)));
+
+	text = g_strdup (gtk_entry_get_text (GTK_ENTRY (OID ("DictionaryPathEntry"))));
 	/* TODO call format check on this word list */
 	/* TODO call rebuild internal word completion list */
 	gok_log_x ("TODO: Call to check file for expected format on file [%s]", text);
-	
-	if (m_AuxDicts) g_free (m_AuxDicts);
+
+	g_free (m_AuxDicts);
 	m_AuxDicts = text;
+
 	gok_log_leave();
 }
 
 void 
 gok_page_wordcomplete_initialize_auxwordlist_control (const char* file)
 {
-	GtkWidget* pWidget; 
-	
 	gok_log_enter();
-	pWidget = glade_xml_get_widget (gok_settingsdialog_get_xml(), "DictionaryPathEntry");
-	g_assert (pWidget != NULL);
-	if (file) gtk_entry_set_text ( GTK_ENTRY (pWidget), file);
+	if (file)
+	{
+		gtk_entry_set_text (GTK_ENTRY (OID ("DictionaryPathEntry")), file);
+	}
 	gok_log_leave();
 }
-
-
