@@ -2,6 +2,7 @@
 *
 * Copyright 2002 Sun Microsystems, Inc.
 * Copyright 2002 University Of Toronto
+* Copyright 2009 Gerd Kohlberger <gerdko gmail com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
@@ -2340,22 +2341,25 @@ void gok_scanner_input_motion (gint *motion_data, gint n_axes)
 	GokKeyboard *pKeyboard = gok_main_get_current_keyboard ();
 	GokKey *pKey;
 	GtkWidget *pWindow = gok_main_get_main_window ();
+	GdkWindow *gdk_window;
 	gint x=0, y=0;
-	if ((n_axes >= 2) && pWindow->window) {
+
+	gdk_window = gtk_widget_get_window (pWindow);
+	if ((n_axes >= 2) && gdk_window) {
 		gint o_x, o_y;
 		gdouble multiplier = gok_data_get_valuator_sensitivity ();
 		x = motion_data[0] * multiplier - m_OffsetX;
 		y = motion_data[1] * multiplier - m_OffsetY;
-		gdk_window_get_origin (pWindow->window, &o_x, &o_y);
+		gdk_window_get_origin (gdk_window, &o_x, &o_y);
 		if (!gok_data_get_drive_corepointer ()) {
-			gok_pointer_clip_to_window (&x, &y, pWindow->window, 
+			gok_pointer_clip_to_window (&x, &y, gdk_window,
 						    gok_scanner_get_slop ());
 		}
 		else {
 			GdkWindow *root = 
 				gdk_screen_get_root_window (
 					gdk_drawable_get_screen (
-						pWindow->window));
+						gdk_window));
 			gok_pointer_clip_to_window (&x, &y, root, 0);
 		}
 		motion_data[0] = x;
@@ -2400,7 +2404,7 @@ void gok_scanner_input_motion_libusb (gint x, gint y)
 	y = y * multiplier;
 
 	/* clip coordinates to window */
-	gdk_drawable_get_size (pWindow->window, &w, &h);
+	gdk_drawable_get_size (gtk_widget_get_window (pWindow), &w, &h);
 	/* horizontal */
 	if (w + slop < offset_x + x) {
 	        /* too far right */
@@ -2449,13 +2453,15 @@ void gok_scanner_input_motion_xevie (gint x, gint y)
 	gint w, h;
 	static gint offset_x = 0, origin_x = 0;
 	static gint offset_y = 0, origin_y = 0;
+	GdkWindow *gdk_window;
 	GokKeyboard *pKeyboard = gok_main_get_current_keyboard ();
 	GtkWidget *pWindow = gok_main_get_main_window ();
 	
 	/* ignore motion events outside window */
-	gdk_drawable_get_size (pWindow->window, &w, &h);
-	gdk_window_get_position (pWindow->window, &offset_x, &offset_y);
-	gdk_window_get_root_origin (pWindow->window, &origin_x, &origin_y);
+	gdk_window = gtk_widget_get_window (pWindow);
+	gdk_drawable_get_size (gdk_window, &w, &h);
+	gdk_window_get_position (gdk_window, &offset_x, &offset_y);
+	gdk_window_get_root_origin (gdk_window, &origin_x, &origin_y);
 	if (x < offset_x || x > offset_x+w ||
 	    y < offset_y || y > offset_y+h) {
 	  gok_scanner_on_key_leave (m_pContainingKey);
