@@ -2,6 +2,7 @@
 *
 * Copyright 2002 Sun Microsystems, Inc.,
 * Copyright 2002 University Of Toronto
+* Copyright 2009 Gerd Kohlberger <gerdko gmail com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
@@ -27,7 +28,7 @@
 #include <sys/stat.h>
 #include <unistd.h>
 #include <string.h>
-#include <glade/glade.h>
+
 #include "gok-settings-dialog.h"
 #include "gok-page-keysizespace.h"
 #include "gok-page-actions.h"
@@ -36,7 +37,6 @@
 #include "gok-page-wordcomplete.h"
 #include "gok-page-keyboard.h"
 #include "gok-page-accessmethod.h"
-#include "gok-glade-helpers.h"
 #include "gok-data.h"
 #include "gok-log.h"
 #include "main.h"
@@ -47,7 +47,7 @@
 static GtkWidget* m_pWindowSettings;
 
 /* pointer to the settings dialog xml data type */
-static GladeXML* m_pXML;
+GtkBuilder *builder;
 
 static gboolean is_locked;
 
@@ -63,23 +63,21 @@ static gboolean is_locked;
 **/
 gboolean gok_settingsdialog_open (gboolean bShow)
 {
-	GladeXML *xml;
-	
-	xml = gok_glade_xml_new("gok.glade2", "dialogSettings");
-	m_pXML = xml;
-	
-	m_pWindowSettings = glade_xml_get_widget(xml, "dialogSettings");
-	g_assert (m_pWindowSettings != NULL);
-	
-	is_locked = FALSE;  /* don't read gconf here */
+	builder = gok_ui_helper_load_file ("gok-settingsdialog.ui");
+	g_assert (builder != NULL);
+
+	m_pWindowSettings = WID ("window");
+
+	/* don't read gconf here */
+	is_locked = FALSE;
 
 	/* initialize all the pages */
-	gok_settings_page_keysizespace_initialize (xml);
-	gok_page_accessmethod_initialize (xml);
-	gok_page_keyboard_initialize (xml);
-	gok_page_actions_initialize (xml);
-	gok_page_feedbacks_initialize (xml);
-	gok_page_wordcomplete_initialize (xml);
+	gok_settings_page_keysizespace_initialize ();
+	gok_page_accessmethod_initialize ();
+	gok_page_keyboard_initialize ();
+	gok_page_actions_initialize ();
+	gok_page_feedbacks_initialize ();
+	gok_page_wordcomplete_initialize ();
 	
 	/* create a backup copy of all the settings */
 	gok_data_backup_settings();
@@ -114,16 +112,16 @@ gboolean gok_settingsdialog_show()
 	
 	if (was_locked != is_locked) {
 		if (!is_locked) {
-			gtk_widget_show(glade_xml_get_widget(m_pXML, "ActionsTab"));
-			gtk_widget_show(glade_xml_get_widget(m_pXML, "AccessMethodsTab"));
+			gtk_widget_show (WID ("ActionsTab"));
+			gtk_widget_show (WID ("AccessMethodsTab"));
 		}
 		else {
-			gtk_widget_hide(glade_xml_get_widget(m_pXML, "ActionsTab"));
-			gtk_widget_hide(glade_xml_get_widget(m_pXML, "AccessMethodsTab"));
+			gtk_widget_hide (WID ("ActionsTab"));
+			gtk_widget_hide (WID ("AccessMethodsTab"));
 		}
 	}
 
-	bFirstShowing = (GDK_IS_DRAWABLE(m_pWindowSettings->window) == FALSE) ? TRUE : FALSE;
+	bFirstShowing = !gtk_widget_is_drawable (m_pWindowSettings);
 
 	gtk_widget_show (m_pWindowSettings);
 
@@ -159,22 +157,11 @@ GtkWidget* gok_settingsdialog_get_window ()
  	return m_pWindowSettings;
 }
 
-/**
-* gok_settingsdialog_get_xml
-*
-* returns: A pointer to the settings dialog glade xml data type.
-**/
-GladeXML* gok_settingsdialog_get_xml ()
-{
- 	return m_pXML;
-}
-
 /**
 * gok_settingsdialog_close
 * 
 * Destroys the GOK settings dialog.
 *
-* returns: void
 **/
 void gok_settingsdialog_close()
 {
@@ -183,6 +170,7 @@ void gok_settingsdialog_close()
 	{
 		gok_page_accessmethod_close();
 		gtk_widget_destroy (m_pWindowSettings);
+		g_object_unref (builder);
 	}
 	else
 	{
@@ -337,17 +325,9 @@ void on_button_cancel (GtkButton* pButton, gpointer user_data)
 **/
 void on_button_help (GtkButton* pButton, gpointer user_data)
 {
-	GtkWidget* pNotebook;
 	const char* help_link_id = NULL;
-	
-	pNotebook = glade_xml_get_widget (m_pXML, "notebook1");
-	if (pNotebook == NULL)
-	{
-		gok_log_x ("Can't find notebook!\n");
-		return;
-	}
-	
-	switch (gtk_notebook_get_current_page (GTK_NOTEBOOK (pNotebook)))
+
+	switch (gtk_notebook_get_current_page (GTK_NOTEBOOK (OID ("notebook1"))))
 	{
 		case 0:
 			help_link_id = "gok-prefs-appearance";
@@ -409,15 +389,158 @@ void gok_settingsdialog_backup_settings ()
 	gok_data_backup_settings();
 }
 
-/**
-* gok_settingsdialog_sort
-* @pItem1: pointer to item #1.
-* @pItem2: pointer to item #2.
-*
-* returns: 0 if the items are the same, -1 if pItem1 is less than pItem 2.
-* Returns 1 if pItem1 is greater than pItem2.
-**/
-gint gok_settingsdialog_sort (gconstpointer pItem1, gconstpointer pItem2)
+/*
+ * gok_settingsdialog_combobox_sort:
+ * @model: A #GtkTreeModel
+ * @a: Iter pointing to a row
+ * @b: Iter pointing to another row
+ * @data: User data
+ *
+ * Alpha-numeric compare func. UTF-8.
+ *
+ * Returns: 0 if the items are the same, -1 if a is less than b,
+ *          1 if a is greater than b.
+ */
+static gint
+gok_settingsdialog_combobox_sort (GtkTreeModel *model,
+				  GtkTreeIter  *a,
+				  GtkTreeIter  *b,
+				  gpointer      data)
 {
-	return strcmp (pItem1, pItem2);
+	gchar *str_a, *str_b;
+	gint ret = 0;
+
+	gtk_tree_model_get (model, a, COL_TEXT, &str_a, -1);
+	gtk_tree_model_get (model, b, COL_TEXT, &str_b, -1);
+
+
+	if (str_a == NULL || str_b == NULL)
+	{
+		if (str_a == NULL && str_b == NULL)
+			return 0; /* both equal */
+
+		ret = (str_a == NULL) ? -1 : 1;
+	}
+	else
+	{
+		ret = g_utf8_collate (str_a, str_b);
+	}
+
+	g_free (str_a);
+	g_free (str_b);
+
+	return ret;
+}
+
+/**
+ * gok_settingsdialog_combobox_init:
+ * @combo: A #GtkComboBox
+ * @sortalbe: Whether the model should be sortable
+ *
+ * Utility function to intitialize @combo.
+ *
+ * The initialization is similar to gtk_combo_box_new_text, to
+ * allow the use of the 'simple text-only API' for combo boxes.
+ */
+void
+gok_settingsdialog_combobox_init (GtkComboBox *combo,
+				  gboolean     sortable)
+{
+	GtkListStore *model;
+	GtkCellRenderer *cell;
+
+	g_return_if_fail (GTK_IS_COMBO_BOX (combo));
+
+	/* model */
+	model = gtk_list_store_new (N_COLUMNS, G_TYPE_STRING);
+	gtk_combo_box_set_model (combo, GTK_TREE_MODEL (model));
+
+	/* text renderer */
+	cell = gtk_cell_renderer_text_new ();
+	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), cell, TRUE);
+	gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), cell,
+					"text", COL_TEXT, NULL);
+
+	/* sorting */
+	if (sortable)
+	{
+		gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (model),
+						 COL_TEXT,
+						 gok_settingsdialog_combobox_sort,
+						 NULL, NULL);
+		gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (model),
+						      COL_TEXT,
+						      GTK_SORT_ASCENDING);
+	}
+	g_object_unref (model);
+}
+
+/**
+ * gok_settingsdialog_combobox_search:
+ * @combo: A #GtkComboBox
+ * @item: The item to search for
+ * @iter_return: Return location for iter
+ *
+ * Searches for @item in @combo. @iter_return will point to the location of
+ * @item. If the function returns #FALSE, @iter_return will be invalid.
+ *
+ * Returns: #TRUE if @item was found, #FALSE otherwise
+ */
+gboolean
+gok_settingsdialog_combobox_search (GtkComboBox *combo,
+				    const gchar *item,
+				    GtkTreeIter *iter_return)
+{
+	GtkTreeModel *model;
+	gchar *str;
+
+	g_return_val_if_fail (GTK_IS_COMBO_BOX (combo), FALSE);
+	g_return_val_if_fail (iter_return != NULL, FALSE);
+
+	model = gtk_combo_box_get_model (combo);
+	if (gtk_tree_model_get_iter_first (model, iter_return))
+	{
+		do
+		{
+			gtk_tree_model_get (model, iter_return, COL_TEXT, &str, -1);
+			if (g_strcmp0 (item, str) == 0)
+			{
+				g_free (str);
+				return TRUE;
+			}
+			g_free (str);
+		}
+		while (gtk_tree_model_iter_next (model, iter_return));
+	}
+	return FALSE;
+}
+
+/**
+ * gok_settingsdialog_combobox_set_active:
+ * @combo: a #GtkComboBox
+ * @item: The item to show
+ *
+ * Set @item as the current seletction in @combo.
+ */
+void
+gok_settingsdialog_combobox_set_active (GtkComboBox *combo,
+					const gchar *item)
+{
+	GtkTreeModel *model;
+	GtkTreeIter iter;
+
+	g_return_if_fail (GTK_IS_COMBO_BOX (combo));
+	g_return_if_fail (item != NULL);
+
+	if (!gok_settingsdialog_combobox_search (combo, item, &iter))
+	{
+		/* fall back to first item */
+		model = gtk_combo_box_get_model (combo);
+		if (!gtk_tree_model_get_iter_first (model, &iter))
+		{
+			/* combo box is empty */
+			return;
+		}
+	}
+	gtk_combo_box_set_active_iter (combo, &iter);
 }
