@@ -20,7 +20,9 @@
 */
 
 #include <string.h>
-#include <gnome.h>
+#include <glib.h>
+#include <glib/gi18n.h>
+
 #include "gok-log.h"
 #include "gok-utf8-word-complete.h"
 
@@ -73,13 +75,12 @@ static void utf8_word_prediction_free (WordPrediction *prediction);
 
 /* 
  * This macro initializes GokUtf8WordComplete with the GType system 
- *   and defines ..._class_init and ..._instance_init functions 
+ *   and defines ..._class_init and ..._init functions and a ..._parent_class pointer
  */
-GNOME_CLASS_BOILERPLATE (GokUTF8WordComplete, gok_utf8_wordcomplete,
-			 GokWordComplete, GOK_TYPE_WORDCOMPLETE)
+G_DEFINE_TYPE (GokUTF8WordComplete, gok_utf8_wordcomplete, GOK_TYPE_WORDCOMPLETE)
 
 static void
-gok_utf8_wordcomplete_instance_init (GokUTF8WordComplete *complete)
+gok_utf8_wordcomplete_init (GokUTF8WordComplete *complete)
 {
 	complete->word_list = NULL;
 	complete->word_list_end = NULL;
@@ -91,7 +92,7 @@ gok_utf8_wordcomplete_instance_init (GokUTF8WordComplete *complete)
 static void
 gok_utf8_wordcomplete_class_init (GokUTF8WordCompleteClass *klass)
 {
-	GokWordCompleteClass *word_complete_class = (GokWordCompleteClass *) klass;
+	GokWordCompleteClass *word_complete_class = GOK_WORDCOMPLETE_CLASS (klass);
 	word_complete_class->open = utf8_wordcomplete_open;
 	word_complete_class->close = utf8_wordcomplete_close;
 	word_complete_class->predict_string = utf8_wordcomplete_predict_string;
@@ -232,7 +233,7 @@ utf8_wordcomplete_predict_string (GokWordComplete *complete, const gchar* word,
 		GList *start, *end;
 		gunichar unicode_char = g_utf8_get_char (word);
 		if (utf8_complete->unicode_start_hash)
-			start = g_hash_table_lookup (utf8_complete->unicode_start_hash, (gpointer) unicode_char);
+			start = g_hash_table_lookup (utf8_complete->unicode_start_hash, GUINT_TO_POINTER (unicode_char));
 		if (start)
 		{
 			utf8_complete->start_search = start;
@@ -240,14 +241,13 @@ utf8_wordcomplete_predict_string (GokWordComplete *complete, const gchar* word,
 		else
 			utf8_complete->start_search = utf8_complete->word_list;
 		if (utf8_complete->unicode_end_hash)
-			end = g_hash_table_lookup (utf8_complete->unicode_end_hash, (gpointer) unicode_char);
+			end = g_hash_table_lookup (utf8_complete->unicode_end_hash, GUINT_TO_POINTER (unicode_char));
 		if (end)
 		{
 			utf8_complete->end_search = end;
 		}
 		else
 			utf8_complete->end_search = utf8_complete->word_list_end;
-;
 	}
 
 	word_predict_list = g_new0 (gchar *, num_predictions + 1); /* NULL-terminated */
@@ -709,13 +709,13 @@ utf8_wordcomplete_create_unicode_hash (GokUTF8WordComplete *complete)
 		{
 			/* search for previous entry, just in case locale's collation 
 			   sequence puts things in an 'unusual' order */
-			if (!g_hash_table_lookup (complete->unicode_start_hash, (gpointer) unicode_char)) 
+			if (!g_hash_table_lookup (complete->unicode_start_hash, GUINT_TO_POINTER (unicode_char)))
 			{
-				g_hash_table_insert (complete->unicode_start_hash, (gpointer) unicode_char, next);
+				g_hash_table_insert (complete->unicode_start_hash, GUINT_TO_POINTER (unicode_char), next);
 			}
 			if (prev_char)
 			{
-				g_hash_table_insert (complete->unicode_end_hash, (gpointer) prev_char, next);
+				g_hash_table_insert (complete->unicode_end_hash, GUINT_TO_POINTER (prev_char), next);
 			}
 			prev_char = unicode_char;
 		}
