@@ -33,6 +33,8 @@ use wnck_window_is_active to figure out which window in list is active (since no
 
 
 #include <libwnck/libwnck.h>
+#include <glib.h>
+#include <glib/gi18n.h>
 #include "gok-log.h"
 #include "main.h"
 #include "gok-windowlister.h"
@@ -131,7 +133,6 @@ _wnck_activate_workspace (Screen *screen,
 void
 _modified_wnck_window_activate (WnckWindow *window)
 {
-  Screen  *screen;
   Window   xid;
   XWindowAttributes attrs;
 
@@ -148,7 +149,6 @@ void
 _modified_wnck_workspace_activate (WnckWorkspace *space,
 				   WnckWindow    *window)
 {
-  Screen  *screen;
   Window   xid;
   XWindowAttributes attrs;
 
